@@ -2,12 +2,12 @@ package Net::GitHub::Project::Role;
 
 use Moose::Role;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 # http://github.com/fayland/perl-net-github/tree/master
-has 'owner' => ( isa => 'Str', is => 'rw' );
-has 'name'  => ( isa => 'Str', is => 'rw' );
+has 'owner' => ( isa => 'Str', is => 'rw', required => 1 );
+has 'name'  => ( isa => 'Str', is => 'rw', required => 1 );
 
 sub args_to_pass {
     my $self = shift;
@@ -36,7 +36,7 @@ Net::GitHub::Project::Role - Common between Net::GitHub::Project::* libs
 
 =head1 DESCRIPTION
 
-=head1 METHODS
+=head1 ATTRIBUTES
 
 =over 4
 
@@ -50,6 +50,14 @@ Net::GitHub::Project::Role - Common between Net::GitHub::Project::* libs
 
 =back
 
+=head1 METHODS
+
+=over 4
+
+=item args_to_pass
+
+=back
+
 =head1 AUTHOR
 
 Fayland Lam, C<< <fayland at gmail.com> >>
