@@ -2,7 +2,7 @@ package Net::GitHub::Role;
 
 use Moose::Role;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 use JSON::Any;
@@ -13,8 +13,10 @@ use Data::Dumper;
 has 'debug' => ( is => 'rw', isa => 'Str', default => 0 );
 
 # login
-has 'email' => ( isa => 'Str', is => 'rw', default => '' );
+has 'login'  => ( is => 'rw', isa => 'Str', default => '' );
 has 'password' => ( isa => 'Str', is => 'rw', default => '' );
+has 'token' => ( is => 'rw', isa => 'Str', default => '' );
+has 'is_signin' => ( is => 'rw', isa => 'Bool', default => 0 );
 
 # api
 has 'api_url' => ( is => 'ro', default => 'http://github.com/api/v1/json/');
@@ -59,6 +61,35 @@ sub get {
     }
 }
 
+sub signin {
+    my $self = shift;
+    
+    return 1 if $self->is_signin;
+    
+    if ( scalar @_ == 2 ) {
+        $self->login = $_[0];
+        $self->password = $_[1];
+    }
+    
+    croak "login(login, password)" unless $self->login and $self->password;
+    
+    my $mech = $self->ua;
+    $mech->get( "https://github.com/login" );
+    croak "Couldn't recognize login page!\n" unless $mech->content =~ /Login/;
+
+    $mech->submit_form(
+		form_number => 1,
+		fields      => {
+			login     => $self->login,
+			password  => $self->password,
+			commit    => 'Log in',
+		}
+    );
+
+    $self->is_login = 1;
+    return 1;
+}
+
 no Moose::Role;
 
 1;
@@ -77,6 +108,18 @@ Net::GitHub::Role - Common between Net::GitHub::* libs
 
 =head1 DESCRIPTION
 
+=head1 ATTRIBUTES
+
+=over 4
+
+=item login
+
+=item password
+
+=item token
+
+=back
+
 =head1 METHODS
 
 =over 4
@@ -93,6 +136,12 @@ instance of L<JSON::Any>
 
 wrap ua->get with success check
 
+=item signin
+
+    $self->signin( $login, $password );
+
+login through L<https://github.com/login> by $self->ua
+
 =back
 
 =head1 AUTHOR
